==> RegScale_CLI-5.54.0-py3-none-any.whl: regscale/core/app/logz.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" Rich Logging """

# standard python imports
import logging
import os
import tempfile
from logging.handlers import TimedRotatingFileHandler
from typing import Any, Optional

import click
from rich.logging import RichHandler
from rich.traceback import install

from regscale import exceptions

if not os.getenv("REGSCALE_DEBUG", False):
    install(suppress=[click, exceptions])


def create_logger(propagate: Optional[bool] = None, custom_handler: Optional[Any] = None) -> logging.Logger:
    """
    Create a logger for use in all cases

    :param Optional[bool] propagate: Whether to propagate the logger, defaults to None
    :param Optional[Any] custom_handler: Custom handler to add to the logger, defaults to None
    :return: logger object
    :rtype: logging.Logger
    """
    loglevel = os.environ.get("LOGLEVEL", "INFO").upper()
    rich_handler = RichHandler(rich_tracebacks=False, markup=True)
    file_handler = TimedRotatingFileHandler(
        filename=f"{tempfile.gettempdir()}{os.sep}RegScale.log",
        when="D",
        interval=3,
        backupCount=10,
    )

    logging.getLogger("botocore").setLevel(logging.CRITICAL)
    logging.basicConfig(
        level=loglevel,
        format="%(asctime)s [%(levelname)-5.5s]  %(message)s",
        datefmt="[%Y/%m/%d %H:%M;%S]",
        handlers=([rich_handler, file_handler, custom_handler] if custom_handler else [rich_handler, file_handler]),
    )
    logger = logging.getLogger("rich")
    if propagate is not None:
        logger.propagate = propagate
    return logger

==> RegScale_CLI-5.62.0-py3-none-any.whl: regscale/core/app/logz.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" Rich Logging """

# standard python imports
import logging
import os
import tempfile
from logging.handlers import TimedRotatingFileHandler
from typing import Any, Optional

import click
from rich.logging import RichHandler
from rich.traceback import install
from rich.console import Console

from regscale import exceptions

if not os.getenv("REGSCALE_DEBUG", False):
    install(suppress=[click, exceptions])


def create_logger(propagate: Optional[bool] = None, custom_handler: Optional[Any] = None) -> logging.Logger:
    """
    Create a logger for use in all cases

    :param Optional[bool] propagate: Whether to propagate the logger, defaults to None
    :param Optional[Any] custom_handler: Custom handler to add to the logger, defaults to None
    :return: logger object
    :rtype: logging.Logger
    """
    loglevel = os.environ.get("LOGLEVEL", "INFO").upper()
    console = Console(width=int(os.environ.get("REGSCALE_LOG_WIDTH", 120)))
    rich_handler = RichHandler(rich_tracebacks=False, markup=True, console=console, show_time=False)
    file_handler = TimedRotatingFileHandler(
        filename=f"{tempfile.gettempdir()}{os.sep}RegScale.log",
        when="D",
        interval=3,
        backupCount=10,
    )

    logging.getLogger("botocore").setLevel(logging.CRITICAL)
    logging.basicConfig(
        level=loglevel,
        format="%(asctime)s [%(levelname)-5.5s]  %(message)s",
        datefmt="[%Y/%m/%d %H:%M;%S]",
        handlers=([rich_handler, file_handler, custom_handler] if custom_handler else [rich_handler, file_handler]),
    )
    logger = logging.getLogger("rich")
    if propagate is not None:
        logger.propagate = propagate
    return logger
